!Apprendre l'anglais:Cours d'anglais,jeux,exercices,grammaire,tests-Enseigner l'anglais
Author: Laurent Camus
Description: Cours d'anglais gratuits pour apprendre l'anglais. Cours d'anglais gratuits pour enseigner l'anglais. Par un professeur d'anglais.
Keywords: anglais,apprendre,ESL,EFL,cours,grammaire,jeux,exercices,tests,blagues,chat,forums,débutant,englais

- Cours gratuits
- Culture
- Jeux
- TousLesCours
- Outils
- Nos sites

Cours Aventures de Thierry Cours pour débutants Guide de travail Cours de phonétique Exercices d'anglais Avec documents audios Avec documents vidéos Fiches de grammaire Fiches méthodologiques Fiches de vocabulaire Leçons grand format Ressource de la semaine Tests de niveau Tous les autres cours Verbes irréguliers Participer Aide/contact Ajouter aux favoris Classements Continuer mon dernier test Contribuer à la vie du site Créer un test interactif Espace Créateurs Espace Membres Forum de discussions Forum de discussions: nouveautés Livre d'or Livret scolaire Messages internes Mes tests Mes tests: mon livre d'or Modifier mon profil Recherche de correspondants Recommander à un ami Salles de discussions/Chat rooms Signaler un problème Détente Anagrammes (jeu multi-joueurs) Documents audios & vidéos Enigmes visuelles Harry Potter Jeu du coffre Joggle Logiciels gratuits Magazine du jour Millionaire Nouvelles du jour Pause détente Championnat Radios et télés Revue de presse Section détente Tous les jeux Utiles Examens & concours Enregistrer sa voix Histoire & Géographie Magazine du jour Nouveautés du site Programmes officiels Thèmes saisonniers Section enfants Section Professeurs Section webmasters Sélection 9000 sites -- Tous les outils -- Conjuguer Prononcer une phrase Traduire Vérifier l'orthographe 21.000 mots prononcés |

Connectez-vous! Connexion auto [Aide] Nouveau compte 3 millions de comptes créés 100% gratuit! [Avantages] Comme 2 millions de personnes, recevez gratuitement chaque semaine une leçon d'anglais... Cliquez ici! Accueil Aide/Contact Accès rapides Imprimer Lire cet extrait Livre d'or Nouveautés Plan du site Presse Recommander Signaler un bug Traduire cet extrait Webmasters Lien sur votre site > Publicités : > Partenaires : -Jeux gratuits -Traducteur anglais -Nos autres sites |  | Bienvenue sur AnglaisFacile.com - site entièrement gratuit pour apprendre ou réviser l'anglais. TOUS NIVEAUX : débutants, intermédiaire, avancé. Environ 3 millions de visites/mois. [En savoir plus-1ère visite] Nous vous proposons aussi le français, l'espagnol, l'allemand, le néerlandais, l'italien, les mathématiques et bien d'autres matières! (liens tout en haut) [In English] Saturday, December 6th 2014 (page du jour | dire la date) Double-cliquez sur n'importe quel terme à l'écran pour obtenir une traduction [Aide] [Guide d'accueil] Ancien menu
Nouveautés du forum :
Formulation ! (12') | Haiti 's earthquake (23')
Préposition /At (3h38) | Les pluriels (4h12)
Jeu du triplet n° 157 (4h48) | Dürfen avec Accusatif ou Datif... (5h43)
Jeu- mots avec -ling (6h11) | Exercice 23 / Encore différent... (6h17)
Jeu de phrases Nº 2 -Ser -Esta... (6h29) | Juego bilingue N°31 (8h39)
Correction / David Henry (9h05) | Lettre motivation/aide (10h12)
Correction/sport (11h38) | Entendre les accents (11h40)
Building a bridge/aide (11h45) | Verben + Dativ (11h56)
Présentation (12h11) | Past simple /Traduction (13h47)
Nur noch (15h29) | >> Plus (anglais) | >> Plus (Tout) | >> Tous
Anglais Espagnol Français Allemand Maths Italien Néerlandais Culture Clavier Jeux News / Facebook: Recevoir nos nouveautés par RSS ou directement sur Facebook | Voir les 100 derniers ajouts AnglaisFacile.com est un site entièrement gratuit pour apprendre l'anglais gratuitement. Vous y trouverez des cours d'anglais gratuits, des exercices d'anglais gratuits, un forum pour poser vos questions et des outils indispensables pour apprendre l'anglais. Utile pour se perfectionner ou apprendre l'anglais.

Recommander cette page

- Cours gratuits
- Culture
- Jeux
- TousLesCours
- Outils
- Tous nos sites

> INDISPENSABLES : TESTEZ VOTRE NIVEAU | GUIDE DE TRAVAIL | NOS MEILLEURES FICHES | Les fiches les plus populaires | Aide/Contact
> COURS ET TESTS : -ing | AS / LIKE | Abréviations | Accord/Désaccord | Activités | Adjectifs | Adverbes | Alphabet | Animaux | Argent | Argot | Articles | Audio | Auxiliaires | Be | Betty | Chanson | Communication | Comparatifs/Superlatifs | Composés | Conditionnel | Confusions | Conjonctions | Connecteurs | Contes | Contractions | Contraires | Corps | Couleurs | Courrier | Cours | Dates | Dialogues | Dictées | Décrire | Ecole | En attente | Exclamations | Faire faire | Famille | Faux amis | Films | For ou since? | Formation | Futur | Fêtes | Genre | Get | Goûts | Grammaire | Guide | Géographie | Habitudes | Harry Potter | Have | Heure | Homonymes | Impersonnel | Infinitif | Internet | Inversion | Jeux | Journaux | Lettre manquante | Littérature | Magasin | Maison | Majuscules | Make/do? | Maladies | Mars | Matilda | Modaux | Mots | Mouvement | Musique | Mélanges | Méthodologie | Métiers | Météo | Nature | Neige | Nombres | Noms | Nourriture | Négation | Opinion | Ordres | Participes | Particules | Passif | Passé | Pays | Pluriel | Plus-que-parfait | Politesse | Ponctuation | Possession | Poèmes | Present perfect | Pronoms | Prononciation | Proverbes et structures idiomatiques | Prépositions | Présent | Présenter | Quantité | Question | Question Tags | Relatives | Royaume-Uni | Say, tell ou speak? | Sports | Style direct | Subjonctif | Subordonnées | Suggérer quelque chose | Synonymes | Temps | Tests de niveau | There is/There are | Thierry | This/That? | Tous les tests | Tout | Traductions | Travail | Téléphone | USA | Verbes irréguliers | Vidéo | Villes | Voitures | Voyages | Vêtements
> INFORMATIONS : Copyright Laurent Camus - En savoir plus, Aide, Contactez-nous [Conditions d'utilisation] [Conseils de sécurité] Reproductions et traductions interdites sur tout support (voir conditions) | Contenu des sites déposé chaque semaine chez un huissier de justice | Mentions légales / Vie privée / Cookies.
| Cours, leçons et exercices d'anglais 100% gratuits, hors abonnement internet auprès d'un fournisseur d'accès.